==> trame_slicer-0.2.1-py3-none-any.whl: trame_slicer/segmentation/__init__.py <==
from .segment_modifier import ModificationMode, SegmentModifier, vtk_image_to_np
from .segment_paint_widget import BrushModel, BrushShape, SegmentPaintWidget
from .segment_paint_widget_2d import (
    SegmentPaintWidget2D,
    SegmentPaintWidget2DInteractor,
)
from .segment_paint_widget_3d import (
    SegmentPaintWidget3D,
    SegmentPaintWidget3DInteractor,
)
from .segment_properties import SegmentProperties
from .segment_region_mask import MaskedRegion, SegmentRegionMask
from .segment_scissor_widget import (
    ScissorPolygonBrush,
    SegmentScissorWidget,
    SegmentScissorWidgetInteractor,
)
from .segmentation import Segmentation
from .segmentation_effects import (
    SegmentationEffect,
    SegmentationEffectID,
    SegmentationEraseEffect,
    SegmentationPaintEffect,
    SegmentationScissorEffect,
)
from .segmentation_widget import SegmentationWidget

__all__ = [
    "BrushModel",
    "BrushShape",
    "MaskedRegion",
    "ModificationMode",
    "ScissorPolygonBrush",
    "SegmentModifier",
    "SegmentPaintWidget",
    "SegmentPaintWidget2D",
    "SegmentPaintWidget2DInteractor",
    "SegmentPaintWidget3D",
    "SegmentPaintWidget3DInteractor",
    "SegmentProperties",
    "SegmentRegionMask",
    "SegmentScissorWidget",
    "SegmentScissorWidgetInteractor",
    "Segmentation",
    "SegmentationEffect",
    "SegmentationEffectID",
    "SegmentationEraseEffect",
    "SegmentationPaintEffect",
    "SegmentationScissorEffect",
    "SegmentationWidget",
    "vtk_image_to_np",
]

==> trame_slicer-1.0.0-py3-none-any.whl: trame_slicer/segmentation/__init__.py <==
from __future__ import annotations

from .segment_modifier import ModificationMode, SegmentModifier, vtk_image_to_np
from .segment_paint_widget import BrushModel, BrushShape, SegmentPaintWidget
from .segment_paint_widget_2d import (
    SegmentPaintWidget2D,
    SegmentPaintWidget2DInteractor,
)
from .segment_paint_widget_3d import (
    SegmentPaintWidget3D,
    SegmentPaintWidget3DInteractor,
)
from .segment_properties import SegmentProperties
from .segment_region_mask import MaskedRegion, SegmentRegionMask
from .segment_scissor_widget import (
    ScissorPolygonBrush,
    SegmentScissorWidget,
    SegmentScissorWidgetInteractor,
)
from .segmentation import Segmentation, SegmentationOpacityEnum
from .segmentation_effects import (
    SegmentationEffect,
    SegmentationEffectID,
    SegmentationEraseEffect,
    SegmentationPaintEffect,
    SegmentationScissorEffect,
)
from .segmentation_widget import SegmentationWidget

__all__ = [
    "BrushModel",
    "BrushShape",
    "MaskedRegion",
    "ModificationMode",
    "ScissorPolygonBrush",
    "SegmentModifier",
    "SegmentPaintWidget",
    "SegmentPaintWidget2D",
    "SegmentPaintWidget2DInteractor",
    "SegmentPaintWidget3D",
    "SegmentPaintWidget3DInteractor",
    "SegmentProperties",
    "SegmentRegionMask",
    "SegmentScissorWidget",
    "SegmentScissorWidgetInteractor",
    "Segmentation",
    "SegmentationEffect",
    "SegmentationEffectID",
    "SegmentationEraseEffect",
    "SegmentationOpacityEnum",
    "SegmentationPaintEffect",
    "SegmentationScissorEffect",
    "SegmentationWidget",
    "vtk_image_to_np",
]
